import AutomaticAssessmentConfiguration
import objc
from PyObjCTools.TestSupport import TestCase, min_sdk_level


class TestAEAssessmentSessionDelegateHelper(AutomaticAssessmentConfiguration.NSObject):
    def assessmentSessionDidBegin_(self, a):
        pass

    def assessmentSessionDidFailToBegin_error_(self, a, b):
        pass

    def assessmentSessionDidInterrupt_error_(self, a, b):
        pass

    def assessmentSessionDidEnd_(self, a):
        pass


class TestAEAssessmentSessionDelegate(TestCase):
    @min_sdk_level("10.15.4")
    def testProtocols(self):
        objc.protocolNamed("AEAssessmentSessionDelegate")



import AutomaticAssessmentConfiguration
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestAEAssessmentApplication(TestCase):
    @min_os_level("12.0")
    def testClasses(self):
        self.assertIsInstance(
            AutomaticAssessmentConfiguration.AEAssessmentApplication, objc.objc_class
        )

    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertResultIsBOOL(
            AutomaticAssessmentConfiguration.AEAssessmentApplication.requiresSignatureValidation
        )
        self.assertArgIsBOOL(
            AutomaticAssessmentConfiguration.AEAssessmentApplication.setRequiresSignatureValidation_,
            0,
        )



import AutomaticAssessmentConfiguration
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestAEAssessmentConfiguration(TestCase):
    @min_os_level("10.15.4")
    def testClasses(self):
        self.assertIsInstance(
            AutomaticAssessmentConfiguration.AEAssessmentConfiguration, objc.objc_class
        )



import AutomaticAssessmentConfiguration
import objc
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestAEAssessmentSession(TestCase):
    @min_os_level("10.15.4")
    def testClasses(self):
        self.assertIsInstance(
            AutomaticAssessmentConfiguration.AEAssessmentSession, objc.objc_class
        )

    @min_os_level("10.15.4")
    def test_methods(self):
        self.assertResultIsBOOL(
            AutomaticAssessmentConfiguration.AEAssessmentSession.isActive
        )



import AutomaticAssessmentConfiguration
from PyObjCTools.TestSupport import TestCase, min_os_level


class TestAEAssessmentParticipantConfiguration(TestCase):
    @min_os_level("12.0")
    def test_methods12_0(self):
        self.assertResultIsBOOL(
            AutomaticAssessmentConfiguration.AEAssessmentParticipantConfiguration.allowsNetworkAccess
        )
        self.assertArgIsBOOL(
            AutomaticAssessmentConfiguration.AEAssessmentParticipantConfiguration.setAllowsNetworkAccess_,
            0,
        )



"""
Python mapping for the AutomaticAssessmentConfiguration framework.

This module does not contain docstrings for the wrapped code, check Apple's
documentation for details on how to use these functions and classes.
"""

import sys

import Foundation
import objc
from . import _metadata
from . import _AutomaticAssessmentConfiguration

sys.modules["AutomaticAssessmentConfiguration"] = mod = objc.ObjCLazyModule(
    "AutomaticAssessmentConfiguration",
    "com.apple.AutomaticAssessmentConfiguration",
    objc.pathForFramework(
        "/System/Library/Frameworks/AutomaticAssessmentConfiguration.framework"
    ),
    _metadata.__dict__,
    None,
    {
        "__doc__": __doc__,
        "objc": objc,
        "__path__": __path__,
        "__loader__": globals().get("__loader__", None),
    },
    (_AutomaticAssessmentConfiguration, Foundation),
)

del sys.modules["AutomaticAssessmentConfiguration._metadata"]



# This file is generated by objective.metadata
#
# Last update: Sun Jul 11 21:23:21 2021
#
# flake8: noqa

import objc, sys

if sys.maxsize > 2 ** 32:

    def sel32or64(a, b):
        return b

else:

    def sel32or64(a, b):
        return a


if objc.arch == "arm64":

    def selAorI(a, b):
        return a

else:

    def selAorI(a, b):
        return b


misc = {}
constants = """$AEAssessmentErrorDomain$"""
enums = """$AEAssessmentErrorUnknown@1$AEAutocorrectModeNone@0$AEAutocorrectModePunctuation@2$AEAutocorrectModeSpelling@1$"""
misc.update({})
r = objc.registerMetaDataForSelector
objc._updatingMetadata(True)
try:
    r(
        b"AEAssessmentApplication",
        b"requiresSignatureValidation",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentApplication",
        b"setRequiresSignatureValidation:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"allowsAccessibilitySpeech",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"allowsActivityContinuation",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"allowsContinuousPathKeyboard",
        {"retval": {"type": b"Z"}},
    )
    r(b"AEAssessmentConfiguration", b"allowsDictation", {"retval": {"type": b"Z"}})
    r(
        b"AEAssessmentConfiguration",
        b"allowsKeyboardShortcuts",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"allowsPasswordAutoFill",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"allowsPredictiveKeyboard",
        {"retval": {"type": b"Z"}},
    )
    r(b"AEAssessmentConfiguration", b"allowsSpellCheck", {"retval": {"type": b"Z"}})
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsAccessibilitySpeech:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsActivityContinuation:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsContinuousPathKeyboard:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsDictation:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsKeyboardShortcuts:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsPasswordAutoFill:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsPredictiveKeyboard:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentConfiguration",
        b"setAllowsSpellCheck:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentParticipantConfiguration",
        b"allowsNetworkAccess",
        {"retval": {"type": b"Z"}},
    )
    r(
        b"AEAssessmentParticipantConfiguration",
        b"setAllowsNetworkAccess:",
        {"arguments": {2: {"type": b"Z"}}},
    )
    r(
        b"AEAssessmentSession",
        b"beginSessionWithConfiguration:completion:",
        {
            "arguments": {
                3: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {
                            0: {"type": b"^v"},
                            1: {"type": b"@"},
                            2: {"type": b"@"},
                        },
                    }
                }
            }
        },
    )
    r(
        b"AEAssessmentSession",
        b"endWithCompletion:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"AEAssessmentSession",
        b"invalidationHandler",
        {
            "retval": {
                "callable": {
                    "retval": {"type": b"v"},
                    "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                }
            }
        },
    )
    r(b"AEAssessmentSession", b"isActive", {"retval": {"type": "Z"}})
    r(
        b"AEAssessmentSession",
        b"setInvalidationHandler:",
        {
            "arguments": {
                2: {
                    "callable": {
                        "retval": {"type": b"v"},
                        "arguments": {0: {"type": b"^v"}, 1: {"type": b"@"}},
                    }
                }
            }
        },
    )
    r(
        b"NSObject",
        b"assessmentSession:failedToBeginWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"assessmentSession:failedToUpdateToConfiguration:error:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}, 4: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"assessmentSession:wasInterruptedWithError:",
        {
            "required": False,
            "retval": {"type": b"v"},
            "arguments": {2: {"type": b"@"}, 3: {"type": b"@"}},
        },
    )
    r(
        b"NSObject",
        b"assessmentSessionDidBegin:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"assessmentSessionDidEnd:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
    r(
        b"NSObject",
        b"assessmentSessionDidUpdate:",
        {"required": False, "retval": {"type": b"v"}, "arguments": {2: {"type": b"@"}}},
    )
finally:
    objc._updatingMetadata(False)
expressions = {}

# END OF FILE
